==> artikulate-19.08.3.tar.xz: artikulate-19.08.3/autotests/unittests/editorsession/test_editorsession.h <==
/*
 *  Copyright 2019  Andreas Cord-Landwehr <cordlandwehr@kde.org>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License or (at your option) version 3 or any later version
 *  accepted by the membership of KDE e.V. (or its successor approved
 *  by the membership of KDE e.V.), which shall act as a proxy
 *  defined in Section 14 of version 3 of the license.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef TEST_EDITORSESSION_H
#define TEST_EDITORSESSION_H

#include <QObject>

class TestEditorSession : public QObject
{
    Q_OBJECT

public:
    TestEditorSession() = default;

private Q_SLOTS:
    /**
     * Called before every test case.
     */
    void init();

    /**
     * Called after every test case.
     */
    void cleanup();

     /**
      * @brief Construct and destruct editor session and test initial values
      */
     void createEditorSession();

     /**
      * @brief Test switching behavior for courses without skeleton.
      */
     void nonSkeletonSwitchingBehavior();

     /**
      * @brief Test handling of skeletons and respective course switching
      */
     void skeletonSwitchingBehavior();

     /**
      * @brief Test for all iterator functionality
      */
     void iterateCourse();
};

#endif

==> artikulate_19.12.3.orig.tar.xz: artikulate-19.12.3/autotests/unittests/editorsession/test_editorsession.h <==
/*
 *  Copyright 2019  Andreas Cord-Landwehr <cordlandwehr@kde.org>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License or (at your option) version 3 or any later version
 *  accepted by the membership of KDE e.V. (or its successor approved
 *  by the membership of KDE e.V.), which shall act as a proxy
 *  defined in Section 14 of version 3 of the license.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef TEST_EDITORSESSION_H
#define TEST_EDITORSESSION_H

#include <QObject>

class TestEditorSession : public QObject
{
    Q_OBJECT

public:
    TestEditorSession() = default;

private Q_SLOTS:
    /**
     * Called before every test case.
     */
    void init();

    /**
     * Called after every test case.
     */
    void cleanup();

    /**
     * @brief Construct and destruct editor session and test initial values
     */
    void createEditorSession();

    /**
     * @brief Test switching behavior for courses without skeleton.
     */
    void nonSkeletonSwitchingBehavior();

    /**
     * @brief Test handling of skeletons and respective course switching
     */
    void skeletonSwitchingBehavior();

    /**
     * @brief Test for all iterator functionality
     */
    void iterateCourse();

    /**
     * @brief Test that the actions are correctly updated when course changes;
     */
    void updateActionsBehavior();
};

#endif
